Reporting Issues
----------------

Feature requests and bug reports for the Python implementation can be posted at
`asdf-coordinates-schemas's github page <https://github.com/asdf-format/asdf-coordinates-schemas>`_.

Contributing Code and Documentation
-----------------------------------

We love contributions! If you're interested in contributing to this project, please open a Pull Request
or issue and we would be glad to work with you.

.. note::
    ASDF-coordinates-schemas is mostly a collection of schemas for the ASDF format. This means that
    in addition to contributing a schema, you will likely also need some code to actually handle
    serializing and deserializing your data. Typically, this code will need to be contributed to
    :ref:`asdf-astropy <asdf-astropy:asdf-astropy>`, which is a separate project. Please link your
    pull requests and issues between the two projects.
